from ObjectListView import ObjectListView, ColumnDefn
import darkMode
import wx

########################################################################
class Book(object):
    """
    Book model for ObjectListView
    """
    #----------------------------------------------------------------------
    def __init__(self, title, author, isbn, mfg):
        self.isbn = isbn
        self.author = author
        self.mfg = mfg       
        self.title = title
    
########################################################################
class MainPanel(wx.Panel):
    
    #----------------------------------------------------------------------
    def __init__(self, parent):
        wx.Panel.__init__(self, parent=parent, id=wx.ID_ANY)
        self.defaultColor = self.GetBackgroundColour()
        self.products = [Book("wxPython in Action", "Robin Dunn",
                              "1932394621", "Manning"),
                         Book("Hello World", "Warren and Carter Sande",
                              "1933988495", "Manning")
                         ]

        self.dataOlv = ObjectListView(self, wx.ID_ANY, style=wx.LC_REPORT|wx.SUNKEN_BORDER)
        self.setBooks()

        # Allow the cell values to be edited when double-clicked
        self.dataOlv.cellEditMode = ObjectListView.CELLEDIT_SINGLECLICK
        
        btn = wx.ToggleButton(self, label="Toggle Dark")
        btn.Bind(wx.EVT_TOGGLEBUTTON, self.onToggleDark)

        # Create some sizers
        mainSizer = wx.BoxSizer(wx.VERTICAL)

        mainSizer.Add(self.dataOlv, 1, wx.ALL|wx.EXPAND, 5)
        mainSizer.Add(btn, 0, wx.ALL, 5)
        self.SetSizer(mainSizer)

    #----------------------------------------------------------------------
    def setBooks(self):
        self.dataOlv.SetColumns([
            ColumnDefn("Title", "left", 120, "title"),
            ColumnDefn("Author", "left", 100, "author"),
            ColumnDefn("ISBN", "right", 100, "isbn"),            
            ColumnDefn("Mfg", "left", 80, "mfg")
        ])
        self.dataOlv.SetObjects(self.products)
            
    #----------------------------------------------------------------------
    def onToggleDark(self, event):
        """"""
        darkMode.darkMode(self, self.defaultColor)
        
########################################################################
class MainFrame(wx.Frame):
    
    #----------------------------------------------------------------------
    def __init__(self):
        wx.Frame.__init__(self, parent=None, id=wx.ID_ANY, 
                          title="MvP OLV Dark Mode Demo")
        panel = MainPanel(self)

class GenApp(wx.App):
    
    #----------------------------------------------------------------------
    def __init__(self, redirect=False, filename=None):
        wx.App.__init__(self, redirect, filename)

    #----------------------------------------------------------------------
    def OnInit(self):
        # create frame here
        frame = MainFrame()
        frame.Show()
        return True
    
#----------------------------------------------------------------------
def main():
    app = GenApp()
    app.MainLoop()
    
#----------------------------------------------------------------------
if __name__ == "__main__":
    main()
